@@ -260,6 +260,9 @@ class OpenCTIConnectorHelper:
         self.opencti_token = get_config_variable(
             "OPENCTI_TOKEN", ["opencti", "token"], config
         )
+        self.opencti_ssl_verify = get_config_variable(
+            "OPENCTI_SSL_VERIFY", ["opencti", "ssl_verify"], config, False, True
+        )
         # Load connector config
         self.connect_id = get_config_variable(
             "CONNECTOR_ID", ["connector", "id"], config
@@ -305,6 +308,7 @@ class OpenCTIConnectorHelper:
             self.connect_auto,
         )
         connector_configuration = self.api.connector.register(self.connector)
+        logging.info("Connector registered with ID:" + self.connect_id)
         self.connector_id = connector_configuration["id"]
         self.work_id = None
         self.applicant_id = connector_configuration["connector_user"]["id"]
@@ -355,7 +359,9 @@ class OpenCTIConnectorHelper:
         listen_queue = ListenQueue(self, self.config, message_callback)
         listen_queue.start()
 
-    def listen_stream(self, message_callback, url=None, token=None) -> None:
+    def listen_stream(
+        self, message_callback, url=None, token=None, verify=None
+    ) -> None:
         """listen for messages and register callback function
 
         :param message_callback: callback function to process messages
@@ -366,14 +372,25 @@ class OpenCTIConnectorHelper:
 
         # Get the last event ID with the "connected" event msg
         if url is not None and token is not None:
+            opencti_ssl_verify = verify if verify is not None else True
+            logging.info(
+                "Starting listening stream events with SSL verify to: "
+                + str(opencti_ssl_verify)
+            )
             messages = SSEClient(
                 url + "/stream",
                 headers={"Authorization": "Bearer " + token},
+                verify=opencti_ssl_verify,
             )
         else:
+            logging.info(
+                "Starting listening stream events with SSL verify to: "
+                + str(self.opencti_ssl_verify)
+            )
             messages = SSEClient(
                 self.opencti_url + "/stream",
                 headers={"Authorization": "Bearer " + self.opencti_token},
+                verify=self.opencti_ssl_verify,
             )
 
         # Create processor thread
